@@ -3,11 +3,11 @@ package XML::Grammar::Fiction::Builder;
 use strict;
 use warnings;
 
-use base 'XML::Grammar::Builder';
+use parent 'XML::Grammar::Builder';
 
 sub get_test_run_test_files
 {
-    return [glob("t/*.t t/*/*.t")]
+    return [ glob("t/*.t t/*/*.t") ];
 }
 
 1;
