@@ -1,5 +1,5 @@
 package XML::Grammar::Fiction::FromProto;
-$XML::Grammar::Fiction::FromProto::VERSION = '0.20.2';
+$XML::Grammar::Fiction::FromProto::VERSION = '0.22.0';
 use strict;
 use warnings;
 use autodie;
@@ -185,7 +185,7 @@ sub _handle_elem_of_name_title
 
     # TODO :
     # Eliminate the Law-of-Demeter-syndrome here.
-    my $list = $elem->_get_childs()->[0];
+    my $list = $elem->_first();
 
     $self->_output_tag(
         {
@@ -321,7 +321,7 @@ on failure.
 
 =head1 VERSION
 
-version 0.20.2
+version 0.22.0
 
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
