@@ -1,5 +1,5 @@
 package XML::Grammar::Fiction::FromProto::Node::WithContent;
-$XML::Grammar::Fiction::FromProto::Node::WithContent::VERSION = '0.20.2';
+$XML::Grammar::Fiction::FromProto::Node::WithContent::VERSION = '0.22.0';
 use strict;
 use warnings;
 
@@ -22,6 +22,13 @@ sub _get_childs
     return $childs || [];
 }
 
+sub _first
+{
+    my ($self) = @_;
+
+    return $self->_get_childs()->[0];
+}
+
 1;
 
 __END__
@@ -37,7 +44,7 @@ with content.
 
 =head1 VERSION
 
-version 0.20.2
+version 0.22.0
 
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
