@@ -1,10 +1,10 @@
 package XML::Grammar::Screenplay::FromProto;
-$XML::Grammar::Screenplay::FromProto::VERSION = '0.20.2';
+$XML::Grammar::Screenplay::FromProto::VERSION = '0.22.0';
 use strict;
 use warnings;
 use autodie;
 
-use Carp;
+use Carp ();
 
 use MooX 'late';
 
@@ -80,8 +80,7 @@ sub _handle_elem_of_name_code_blk
                         ],
                         in => sub {
                             my $inner_text =
-                                $elem->_get_childs()->[0]->_get_childs()->[0]
-                                ->_get_childs()->[0];
+                                $elem->_first()->_first()->_first();
 
                             die if ( ref($inner_text) ne "" );
                             $inner_text =~ s/\A(?:\r?\n)*//ms;
@@ -114,7 +113,7 @@ sub _handle_elem_of_name_img
 {
     my ( $self, $elem ) = @_;
 
-    my $image = sub {
+    my $image_cb = sub {
         return $self->_output_tag_with_childs(
             {
                 start => [
@@ -130,19 +129,13 @@ sub _handle_elem_of_name_img
 
     return (
         ( $self->_writer->ancestor(0) eq $self->_paragraph_tag )
-        ? $image->()
-        : (
-            sub {
-                return $self->_output_tag(
-                    {
-                        start => [ "para", ],
-                        in    => $image,
-
-                        # elem  => [ scalar( $image->() ) ],
-                    }
-                );
+        ? $image_cb->()
+        : $self->_output_tag(
+            {
+                start => [ "para", ],
+                in    => $image_cb,
             }
-        )->()
+        )
     );
 
 }
@@ -261,7 +254,7 @@ Converts the file $path_to_file to XML and returns it.
 
 =head1 VERSION
 
-version 0.20.2
+version 0.22.0
 
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
